package com.yijia.station.service;

import java.util.List;
import com.yijia.station.domain.StationPersonnel;

/**
 * 油站员工信息Service接口
 * 
 * @author yijia
 * @date 2020-12-09
 */
public interface IStationPersonnelService 
{
    /**
     * 查询油站员工信息
     * 
     * @param personnelId 油站员工信息ID
     * @return 油站员工信息
     */
    public StationPersonnel selectStationPersonnelById(Long personnelId);

    /**
     * 查询油站员工信息列表
     * 
     * @param stationPersonnel 油站员工信息
     * @return 油站员工信息集合
     */
    public List<StationPersonnel> selectStationPersonnelList(StationPersonnel stationPersonnel);

    /**
     * 新增油站员工信息
     * 
     * @param stationPersonnel 油站员工信息
     * @return 结果
     */
    public int insertStationPersonnel(StationPersonnel stationPersonnel);

    /**
     * 修改油站员工信息
     * 
     * @param stationPersonnel 油站员工信息
     * @return 结果
     */
    public int updateStationPersonnel(StationPersonnel stationPersonnel);

    /**
     * 批量删除油站员工信息
     * 
     * @param personnelIds 需要删除的油站员工信息ID
     * @return 结果
     */
    public int deleteStationPersonnelByIds(Long[] personnelIds);

    /**
     * 删除油站员工信息信息
     * 
     * @param personnelId 油站员工信息ID
     * @return 结果
     */
    public int deleteStationPersonnelById(Long personnelId);
}
